/**
 * A context menu itself
 * @example <caption>Define a context menu</caption>
 * <context-menu id="my-context-menu">
 *   <button type="button">Cut</button>
 *   <button type="button">Copy</button>
 *   <button type="button">Paste</button>
 * </context-menu>
 *
 * @example <caption>Apply the context menu to an element</caption>
 * <div data-context-menu="my-context-menu">
 *   This element is using a custom context menu.
 * </div>
 */
export declare class ContextMenuElement extends HTMLElement {
    /**
     * Function to define the context menu element in the HTML Custom Element Registry
     * @param {string} tag - the tag name for the context menu element
     * @example
     * import { ContextMenuElement } from "@ivteplo/html-context-menu-element"
     * ContextMenuElement.defineAs("context-menu")
     */
    static defineAs(tag: string): void;
    /** @ignore */
    static get observedAttributes(): string[];
    /**
     * Container that has `data-context-menu` set
     * and that has been right clicked on.
     * @returns {HTMLElement|null}
     */
    get currentTarget(): HTMLElement | null;
    /**
     * Object that has been right clicked on.
     * Can be a child of a container that has the `data-context-menu` set.
     * @returns {HTMLElement|null}
     */
    get target(): HTMLElement | null;
    /**
     * @ignore
     * @param {string} name — changed attribute’s name
     * @param {any} _oldValue
     * @param {any} newValue
     */
    attributeChangedCallback(name: string, _oldValue: any, newValue: any): void;
    /**
     * Check whether the context menu is open.
     * @returns {boolean}
     */
    get open(): boolean;
    /** Hide the context menu */
    hide(): void;
    /**
     * Displays the context menu near the specified location
     * @param {number} x - horizontal click location
     * @param {number} y - vertical click location
     * @param {{
             *   currentTarget?: HTMLElement,
             *   target?: HTMLElement
             * }} - objects that triggered the context menu (optional)
     */
    show(x: number, y: number, { target, currentTarget }?: {
        currentTarget?: HTMLElement;
        target?: HTMLElement;
    }): void;
    /** @ignore */
    connectedCallback(): void;
    /**
     * @ignore
     */
    disconnectedCallback(): void;
    #private;
}

/**
 * Element that represents buttons hidden under a dropdown in a context menu.
 * @example
 * <details is="context-menu-group">
 *     <summary>Group name</summary>
 *     <menu>
 *         <button type="button">Item 1</button>
 *         <button type="button">Item 2</button>
 *     </menu>
 * </details>
 */
export declare class ContextMenuGroupElement extends HTMLDetailsElement {
    /**
     * Function to define the context menu group element in the HTML Custom Element Registry
     * @param {string} tag - the tag name for the context menu group element
     * @example
     * import { ContextMenuGroupElement } from "@ivteplo/html-context-menu-element"
     * ContextMenuGroupElement.defineAs("context-menu-group")
     */
    static defineAs(tag: string): void;
    /**
     * @ignore
     */
    static get observedAttributes(): string[];
    /**
     * @ignore
     * Method that gets called whenever the 'open' attribute changes
     * (list of observed attributes is specified in the static method `observedAttributes`)
     * @param {string} name
     * @param {any} _oldValue
     * @param {any} newValue
     */
    attributeChangedCallback(name: string, _oldValue: any, newValue: any): void;
    #private;
}

/**
 * Helper method to define all required components in the HTML custom element registry.
 * @example
 * import { defineElements } from "@ivteplo/html-context-menu-element"
 *
 * // will define <context-menu /> and <details is="context-menu-group" />
 * defineElements()
 */
export declare function defineElements(): void;

export { }
